@@ -1,9 +1,9 @@
 if {[catch {package require Tcl}]} return
 # NOTE: auto_loaded top-level commands shall not be qualified (no leading ::)
 # but all others should.  See auto_qualify for details.
-package ifneeded BWidget 1.9.11 "\
+package ifneeded BWidget 1.9.13 "\
     package require Tk 8.1.1;\
-    [list tclPkgSetup $dir BWidget 1.9.11 {
+    [list tclPkgSetup $dir BWidget 1.9.13 {
 	{arrow.tcl       source {ArrowButton ::ArrowButton::create ::ArrowButton::use}}
 	{labelframe.tcl  source {LabelFrame ::LabelFrame::create ::LabelFrame::use}}
 	{labelentry.tcl  source {LabelEntry ::LabelEntry::create ::LabelEntry::use}}
@@ -32,7 +32,7 @@ package ifneeded BWidget 1.9.11 "\
 	{mainframe.tcl   source {MainFrame ::MainFrame::create ::MainFrame::use}}
 	{listbox.tcl     source {ListBox ::ListBox::create ::ListBox::use}}
 	{tree.tcl        source {Tree ::Tree::create ::Tree::use}}
-	{color.tcl       source {SelectColor ::SelectColor::menu ::SelectColor::dialog ::SelectColor::setcolor}}
+	{color.tcl       source {SelectColor ::SelectColor::menu ::SelectColor::dialog ::SelectColor::setcolor ::SelectColor::setbasecolor}}
 	{dynhelp.tcl     source {::DynamicHelp::configure ::DynamicHelp::use ::DynamicHelp::register ::DynamicHelp::include ::DynamicHelp::add ::DynamicHelp::delete}}
 	{dialog.tcl      source {Dialog ::Dialog::create ::Dialog::use}}
 	{messagedlg.tcl  source {MessageDlg ::MessageDlg::create ::MessageDlg::use}}
